==============
Advanced Usage
==============

The following assumes basic Python programming experience (and
that you have installed Goldilocks and familiarised yourself
with the basics), skip to the end if you think you know what you're doing.


Further Region Handling
-----------------------

Filtering Regions
~~~~~~~~~~~~~~~~~

Excluding Regions
~~~~~~~~~~~~~~~~~

Limiting Regions
~~~~~~~~~~~~~~~~

Custom Strategies
-----------------
